@@ -10,7 +10,7 @@ from struct import pack # for network byte order
 # third party
 from mongrel2 import handler, request
 
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 logger = logging.getLogger(__name__)
 
@@ -57,6 +57,9 @@ class WebsocketError(RuntimeError):
 
 class Request(request.Request):
     """wraps the default Mongrel Request and adds websocket only functionality"""
+    needs_response = True
+    """will be true if a response is needed, false if you don't need to worry about it"""
+
     @property
     def decoded_body(self):
         """
@@ -159,7 +162,7 @@ class Connection(handler.Connection):
         super(Connection, self).__init__(sender_id, sub_addr, pub_addr)
         self.aborted = {}
 
-    def recv_frame(self):
+    def recv(self):
         """
         this wraps frame handling to make it a little easier to deal with
         """
@@ -167,19 +170,21 @@ class Connection(handler.Connection):
 
         while True:
 
-            m2_req = self.recv()
+            m2_req = super(Connection, self).recv()
             logger.info('{} RECEIVED'.format(m2_req.conn_id))
 
             try:
                 ws_req = self.request_class(m2_req)
 
-                if ws_req.is_handshake() or ws_req.is_disconnect():
+                if ws_req.is_handshake():
+                    ws_req.needs_response = True
+
+                elif ws_req.is_disconnect():
                     # drop these through so they can be handled
-                    pass
+                    ws_req.needs_response = False
 
                 elif not ws_req.is_websocket():
-                    self.reply_non_websocket(ws_req)
-                    continue
+                    ws_req.needs_response = True
 
                 elif ws_req.is_close():
                     if self.is_closed(ws_req):
@@ -193,6 +198,7 @@ class Connection(handler.Connection):
                         # we still want to return this request to give the controller a chance to do other cleanup
                         # even though we have done everything we needed to do to close the connection already
                         self.reply_to_close(ws_req)
+                        ws_req.needs_response = False
 
                 else:
 
@@ -246,7 +252,6 @@ class Connection(handler.Connection):
 
     def close_http(self, req, *args, **kwargs):
         """this is a wrapper around reply_http that also closes the connection"""
-
         headers = kwargs.get('headers', {})
         headers.setdefault('Connection', 'close')
         kwargs['headers'] = headers
